@@ -66,11 +66,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		return asyncore.dispatcher.add_channel (self, map)
 
 	def del_channel (self, map=None):
-		fd = self._fileno
-		if map is None:
-			map = self._map
-		if fd in map:
-			del map[fd]
+		dbconnect.AsynDBConnect.del_channel (self, map)
 
 	def handle_expt_event (self):
 		self.handle_expt ()
@@ -108,8 +104,8 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 	def handle_write (self):
 		state = self.poll ()
 		if state == POLL_OK:
-			if not self.cur:
-				self.create_cursor ()
+			if self.cur is None:
+				return self.create_cursor ()
 			self.set_event_time ()
 			self.cur.execute (self.out_buffer)
 			self.out_buffer = ""
@@ -160,6 +156,8 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		dbconnect.AsynDBConnect.close (self, deactive)
 
 	def connect (self, force = 0):
+		self.connecting = True
+		self.connected = False
 		host, port = self.address
 		sock = psycopg2.connect (
 			dbname = self.dbname,
@@ -186,7 +184,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 			raise dbconnect.SQLError ("Empty SQL")
 		return sql
 
-	def execute (self, request):
+	def execute (self, request, *args, **kargs):
 		dbconnect.DBConnect.begin_tran (self, request)
 		self.out_buffer = self._compile (request)
 		if not self.connected and not self.connecting:
