@@ -20,7 +20,7 @@ class Postgres (SynConnect):
     def close_if_over_keep_live (self):
         DBConnect.close_if_over_keep_live (self)
 
-    def execute (self, request):
+    def execute (self, request, *args, **kargs):
         DBConnect.begin_tran (self, request)
         sql = self._compile (request)
 
@@ -66,7 +66,7 @@ class Redis (Postgres):
         self.response = getattr (self.conn, self.request.method) (*self.request.params)
         self.has_result = True
 
-    def execute (self, request):
+    def execute (self, request, *args, **kargs):
         DBConnect.begin_tran (self, request)
         try:
             if not self.connected:
