@@ -45,7 +45,7 @@ class SynConnect (asynpsycopg2.AsynConnect):
 		else:
 			self.connected = True
 
-	def execute (self, request):
+	def execute (self, request, *args, **kargs):
 		dbconnect.DBConnect.begin_tran (self, request)
 		sql = self._compile (request)
 
