@@ -193,10 +193,6 @@ def loop (timeout = 30.0):
 
 	_polling = 0
 
-poll_fun = asyncore.poll
-if os.name == 'posix' and '__pypy__' not in sys.builtin_module_names:
-	poll_fun = asyncore.epoll
-
 def remove_notsocks (map):
 	global _select_errors, _logger
 
@@ -234,8 +230,27 @@ def remove_notsocks (map):
 
 	return killed
 
+PREFER_EPOLL = False
+ALLOWED_POLL_ERROR = 8
+poll_fun = asyncore.poll
+if os.name == 'posix' and '__pypy__' not in sys.builtin_module_names:
+	poll_fun = asyncore.epoll
+	PREFER_EPOLL = True
+poll_errs = 0
+
+def maybe_poll_fallback ():
+	global _logger, poll_fun, poll_errs
+
+	poll_errs += 1
+	if poll_errs > ALLOWED_POLL_ERROR:
+		if poll_fun is asyncore.poll:
+			raise SystemError ('Too many polling error')
+		_logger and _logger ('fallback to asyncore.poll', 'warn')
+		poll_fun = asyncore.poll # fallback
+		poll_errs = 0
+
 def poll_fun_wrap (timeout, map = None):
-	global _logger
+	global _logger, poll_fun, poll_errs
 
 	if map is None:
 		map = asyncore.socket_map
@@ -246,15 +261,20 @@ def poll_fun_wrap (timeout, map = None):
 	try:
 		poll_fun (timeout, map)
 
+	except (SystemError, KeyboardInterrupt):
+		raise
+
 	except (TypeError, OSError) as why:
-		# WSAENOTSOCK
-		remove_notsocks (map)
+		_logger and _logger.trace ()
+		maybe_poll_fallback ()
+		remove_notsocks (map) # WSAENOTSOCK
 
 	except ValueError:
+		_logger and _logger.trace ()
+		maybe_poll_fallback ()
 		# negative file descriptor, testing all sockets
-		killed = remove_notsocks (map)
 		# or too many file descriptors in select(), divide and conquer
-		if not killed:
+		if not remove_notsocks (map):
 			half = int (len (map) / 2)
 			tmap = {}
 			cc = 0
@@ -268,7 +288,17 @@ def poll_fun_wrap (timeout, map = None):
 
 	except:
 		_logger and _logger.trace ()
-		raise
+		if poll_fun is asyncore.poll:
+			raise
+		_logger and _logger ('fallback to asyncore.poll', 'warn')
+		poll_fun = asyncore.poll # fallback
+
+	else:
+		if poll_errs:
+			poll_errs = 0 # reset error count
+			if PREFER_EPOLL:
+				_logger and _logger ('reinstate asyncore.epoll', 'info')
+				poll_fun = asyncore.epoll
 
 def lifetime_loop (timeout = 30.0, count = 0):
 	global _last_maintern
