@@ -764,9 +764,9 @@ _transitions = {
     (StreamState.CLOSED, StreamInputs.SEND_DATA):
         (H2StreamStateMachine.send_on_closed_stream, StreamState.CLOSED),
     (StreamState.CLOSED, StreamInputs.SEND_WINDOW_UPDATE):
-        #(H2StreamStateMachine.send_on_closed_stream, StreamState.CLOSED),
+        (H2StreamStateMachine.send_on_closed_stream, StreamState.CLOSED),
         # Hans Roh May 8, 2020
-        (None, StreamState.CLOSED),
+        #(None, StreamState.CLOSED),
     (StreamState.CLOSED, StreamInputs.SEND_END_STREAM):
         (H2StreamStateMachine.send_on_closed_stream, StreamState.CLOSED),
 }
